@@ -3,6 +3,7 @@ import logging
 import functools
 
 import bizerror
+from fastutils import rsautils
 from fastutils.funcutils import call_with_inject
 from fastutils.typingutils import Number
 from fastutils.typingutils import smart_cast
@@ -128,3 +129,21 @@ def between(field, min, max, include_min=True, include_max=True, annotation=Numb
                     ))
         return functools.wraps(func)(wrapper)
     return wrapper_outer
+
+
+def rsa_decrypt(field, private_key):
+    """Do rsa-decrypt to the given field with private_key.
+    """
+    def wrapper_outer(func):
+        def wrapper(_django_apiview_view_instance):
+            view = _django_apiview_view_instance
+            if field in view.data:
+                field_value = view.data[field]
+                field_data = rsautils.smart_get_binary_data(field_value)
+                plain_data = rsautils.decrypt(field_data, private_key)
+                plain_text = plain_data.decode("utf-8")
+                view.data[field] = plain_text
+            return view.process(func)
+        return functools.wraps(func)(wrapper)
+    return wrapper_outer
+
